@@ -1,7 +1,7 @@
 /*
  * Sleuth Kit Data Model
  *
- * Copyright 2011-2017 Basis Technology Corp.
+ * Copyright 2011-2018 Basis Technology Corp.
  * Contact: carrier <at> sleuthkit <dot> org
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -289,6 +289,7 @@ public class SleuthkitJNI {
 			 *                       should be unique across multiple cases
 			 *                       (e.g., a UUID).
 			 * @param imageFilePaths Full path(s) to the image file(s).
+			 * @param sectorSize     The sector size (use '0' for autodetect).
 			 *
 			 * @throws TskCoreException if a critical error occurs within the
 			 *                          SleuthKit.
@@ -296,14 +297,14 @@ public class SleuthkitJNI {
 			 *                          the SleuthKit (should be OK to continue
 			 *                          the process)
 			 */
-			public void run(String deviceId, String[] imageFilePaths) throws TskCoreException, TskDataException {
+			public void run(String deviceId, String[] imageFilePaths, int sectorSize) throws TskCoreException, TskDataException {
 				long imageHandle = 0;
 				synchronized (this) {
 					if (0 != tskAutoDbPointer) {
 						throw new TskCoreException("Add image process already started");
 					}
 					if (!isCanceled) { //with isCanceled being guarded by this it will have the same value everywhere in this synchronized block
-						imageHandle = openImage(imageFilePaths, false);
+						imageHandle = openImage(imageFilePaths, sectorSize, false);
 						tskAutoDbPointer = initAddImgNat(caseDbPointer, timezoneLongToShort(timeZone), addUnallocSpace, skipFatFsOrphans);
 					}
 					if (0 == tskAutoDbPointer) {
@@ -395,7 +396,28 @@ public class SleuthkitJNI {
 			 */
 			@Deprecated
 			public void run(String[] imageFilePaths) throws TskCoreException, TskDataException {
-				run(null, imageFilePaths);
+				run(null, imageFilePaths, 0);
+			}
+			
+			/**
+			 * Starts the process of adding an image to the case database.
+			 * Either AddImageProcess.commit or AddImageProcess.revert MUST be
+			 * called after calling AddImageProcess.run.
+			 *
+			 * @param deviceId       An ASCII-printable identifier for the
+			 *                       device associated with the image that
+			 *                       should be unique across multiple cases
+			 *                       (e.g., a UUID).
+			 * @param imageFilePaths Full path(s) to the image file(s).
+			 *
+			 * @throws TskCoreException if a critical error occurs within the
+			 *                          SleuthKit.
+			 * @throws TskDataException if a non-critical error occurs within
+			 *                          the SleuthKit (should be OK to continue
+			 *                          the process)
+			 */
+			public void run(String deviceId, String[] imageFilePaths) throws TskCoreException, TskDataException {
+				run(deviceId, imageFilePaths, 0);
 			}
 		}
 
@@ -474,13 +496,15 @@ public class SleuthkitJNI {
 
 	/**
 	 * Enable verbose logging and redirect stderr to the given log file.
+	 * 
+	 * @param logPath the log file path
 	 */
 	public static void startVerboseLogging(String logPath) {
 		startVerboseLoggingNat(logPath);
 	}
 
 	/**
-	 * open the image and return the image info pointer
+	 * Open the image and return the image info pointer.
 	 *
 	 * @param imageFiles the paths to the images
 	 *
@@ -490,16 +514,33 @@ public class SleuthkitJNI {
 	 *                          TSK
 	 */
 	public static long openImage(String[] imageFiles) throws TskCoreException {
-		return openImage(imageFiles, true);
+		return openImage(imageFiles, 0, true);
+	}
+	
+	/**
+	 * Open the image with a specified sector size and return the image info
+	 * pointer.
+	 * 
+	 * @param imageFiles the paths to the images
+	 * @param sSize      the sector size (use '0' for autodetect)
+	 * 
+	 * @return the image info pointer
+	 * 
+	 * @throws TskCoreException exception thrown if critical error occurs within
+	 *                          TSK
+	 */
+	public static long openImage(String[] imageFiles, int sSize) throws TskCoreException {
+		return openImage(imageFiles, sSize, true);
 	}
 
 	/**
-	 * open the image and return the image info pointer This is a temporary
+	 * Open the image and return the image info pointer. This is a temporary
 	 * measure to allow ingest of multiple local disks on the same drive letter.
 	 * We need to clear the cache to make sure cached data from the first drive
 	 * is not used.
 	 *
 	 * @param imageFiles the paths to the images
+	 * @param sSize      the sector size (use '0' for autodetect)
 	 * @param useCache   true if the image handle cache should be used, false to
 	 *                   always go to TSK to open a fresh copy
 	 *
@@ -508,7 +549,7 @@ public class SleuthkitJNI {
 	 * @throws TskCoreException exception thrown if critical error occurs within
 	 *                          TSK
 	 */
-	private static long openImage(String[] imageFiles, boolean useCache) throws TskCoreException {
+	private static long openImage(String[] imageFiles, int sSize, boolean useCache) throws TskCoreException {
 
 		long imageHandle;
 
@@ -531,7 +572,7 @@ public class SleuthkitJNI {
 				imageHandle = HandleCache.imageHandleCache.get(imageKey);
 			} else {
 				//open new handle and cache it
-				imageHandle = openImgNat(imageFiles, imageFiles.length);
+				imageHandle = openImgNat(imageFiles, imageFiles.length, sSize);
 				HandleCache.fsHandleCache.put(imageHandle, new HashMap<Long, Long>());
 				HandleCache.imageHandleCache.put(imageKey, imageHandle);
 			}
@@ -967,6 +1008,8 @@ public class SleuthkitJNI {
 	 * Close a particular open lookup database. Existing handles are not
 	 * affected.
 	 *
+	 * @param dbHandle Handle of database to close.
+	 * 
 	 * @throws TskCoreException exception thrown if critical error occurs within
 	 *                          TSK
 	 */
@@ -977,7 +1020,9 @@ public class SleuthkitJNI {
 	/**
 	 * Get the name of the database
 	 *
-	 * @param dbHandle previously opened hash db handle
+	 * @param dbHandle Previously opened hash db handle.
+	 * 
+	 * @return The display name.
 	 *
 	 * @throws TskCoreException if a critical error occurs within TSK core
 	 */
@@ -988,7 +1033,7 @@ public class SleuthkitJNI {
 	/**
 	 * Lookup the given hash value and get basic answer
 	 *
-	 * @param hash     Hash value to search for
+	 * @param hash     Hash value to search for.
 	 * @param dbHandle Handle of database to lookup in.
 	 *
 	 * @return True if hash was found in database.
@@ -1094,7 +1139,9 @@ public class SleuthkitJNI {
 	/**
 	 * Fills in any gaps in the image created by image writer.
 	 *
-	 * @param imgHandle
+	 * @param imgHandle The image handle.
+	 * 
+	 * @return 0 if no errors occurred; 1 otherwise.
 	 *
 	 * @throws TskCoreException exception thrown if critical error occurs within
 	 *                          TSK
@@ -1206,7 +1253,7 @@ public class SleuthkitJNI {
 
 	private static native long commitAddImgNat(long process) throws TskCoreException;
 
-	private static native long openImgNat(String[] imgPath, int splits) throws TskCoreException;
+	private static native long openImgNat(String[] imgPath, int splits, int sSize) throws TskCoreException;
 
 	private static native long openVsNat(long imgHandle, long vsOffset) throws TskCoreException;
 
